#
# spec file for package greetd
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{?suse_version} >= 1550
  %define _config_norepl %nil
%else
  %define _pam_confdir %{_sysconfdir}/pam.d
  %define _config_norepl %config(noreplace)
%endif

Name:           greetd
Version:        0.9.0
Release:        1.3
Summary:        Minimal and flexible login manager daemon
License:        GPL-3.0-only
Group:          System/Management
URL:            https://git.sr.ht/~kennylevinsen/greetd
Source:         %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
Source2:        cargo_config
Source3:        greetd.pam
BuildRequires:  cargo
BuildRequires:  cargo-packaging
BuildRequires:  pam-devel
BuildRequires:  systemd-rpm-macros
Requires(post): diffutils
Requires(pre):  %{_bindir}/getent
Requires(pre):  %{_sbindir}/groupadd
Requires(pre):  %{_sbindir}/useradd
Requires(pre):  group(video)
Requires:       pam

%description
greetd is a login manager daemon. greetd on its own does not have any user interface,
but instead offloads that to greeters, which are arbitrary applications that implement the greetd IPC protocol.

%prep
%setup -qa1
mkdir .cargo
cp %{SOURCE2} .cargo/config

%build
%{cargo_build}

%install

install -D -p -m 0755 target/release/%{name} %{buildroot}%{_bindir}/%{name}
install -D -p -m 0755 target/release/agreety %{buildroot}%{_bindir}/agreety

# https://github.com/openSUSE/openSUSEway/issues/37
sed -i -e "s|\$SHELL|bash|" config.toml
install -D -p -m 0644 config.toml %{buildroot}/%{_sysconfdir}/%{name}/config.toml

install -D -m 0644 %{name}.service %{buildroot}/%{_unitdir}/%{name}.service

install -D -m 0644 %{SOURCE3} %{buildroot}/%{_pam_confdir}/greetd

install -d %{buildroot}%{_localstatedir}/cache/greetd
install -d %{buildroot}%{_localstatedir}/lib/greetd
install -d %{buildroot}/run/greetd

%pre
%service_add_pre %{name}.service
getent group greeter >/dev/null || %{_sbindir}/groupadd -r greeter
getent passwd greeter >/dev/null || %{_sbindir}/useradd -r -g greeter -G video -s /bin/false \
	-c "%{name} daemon" -d %{_localstatedir}/lib/greetd greeter
%{_sbindir}/usermod -g greeter -G video -s /bin/false greeter 2> /dev/null

%post
%service_add_post %{name}.service

%preun
%service_del_preun %{name}.service

%postun
%service_del_postun_without_restart %{name}.service

%files
%license LICENSE
%doc README.md
%{_bindir}/%{name}
%{_bindir}/agreety
%{_unitdir}/%{name}.service
%dir %{_sysconfdir}/%{name}
%attr(644,greeter,greeter) %config(noreplace) %{_sysconfdir}/%{name}/config.toml
%_config_norepl %{_pam_confdir}/greetd
%ghost %attr(711,root,greeter) %dir /run/greetd/
%ghost %attr(750,greeter,greeter) %dir %{_localstatedir}/lib/greetd/
%ghost %dir %{_localstatedir}/cache/greetd/

%changelog
* Mon Jan 30 2023 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Update to version 0.9.0:
  * Revert "Remove 'env' from start_session"
  * ipc: ensure backward compatibility of the protocol
  * Change order of setting pam environment variables
  * fakegreet: reset state on errors
  * For FUSE-based home folders, chdir into them as the user instead of root
  * Use /bin/sh instead of $SHELL
  * cargo: Update dependencies
* Tue Aug  2 2022 llyyr <llyyr.public@gmail.com>
- Put greetd.pam in the right directory.
  greetd checks for the pam file in /etc/pam.d/, not in /lib/pam.d/
* Wed May 25 2022 William Brown <william.brown@suse.com>
- Update vendored dependencies
- Correct ordering of _service entries due to a recompress confusion
* Wed Mar 23 2022 Franck Bui <fbui@suse.com>
- spec: /etc/pam.d/greetd should be %%config(noreplace) on SLE
* Mon Mar 14 2022 Franck Bui <fbui@suse.com>
- spec: don't directly use %%{_distconfdir}, it's broken on SLE
  We should instead make use of %%_pam_vendordir but its definition is also
  broken on SLE... hence let define our own macro for now.
* Fri Jan  7 2022 William Brown <william.brown@suse.com>
- resolve bsc#1194119 (CVE-2021-45710)
* Sun Oct 24 2021 Denys Kondratenko <stdden@opensuse.org>
- Version bump to 0.8.0
  * deps: update tokio to 1.0
  * deps: update nix and other dependencies
  * Ensure initial session is only run once.
  * recommend making config world readable rather than setting owner
  * Update lock file
  * readme: Add discuss section
  * docs: Fix scdoc syntax for greetd.5
  * rustfmt: Change merge_imports to imports_granularity
  * ipc: Fix tokio codec
  * Add makefile for man pages
  * greetd: add terminal switch flag configuration option
* Tue Sep 28 2021 William Brown <william.brown@suse.com>
- Replace rust-packaging with cargo-packaging
* Mon May 17 2021 Denys Kondratenko <stdden@opensuse.org>
- provide real shell in example conf
  * fixes # https://github.com/openSUSE/openSUSEway/issues/37
* Tue Mar 23 2021 Michal Hrusecky <michal.hrusecky@opensuse.org>
- avoid restarts on update by using %%service_del_postun_without_restart
* Sat Jan 30 2021 Andrés Barrantes Silman <andresbs@opensuse.org>
- Version bump to 0.7.0
  * Use additional pam service config for greeter
  * greetd: Added tuigreet to known greeters list.
  * terminal: Use direct open, proper errors
  * worker: Unconditionally set up tty
  * terminal: Forcibly take terminal
  * session: Do not log pam_conv after start
  * ci: Build both arch and alpine
  * Use per-pid socket paths
  * Terminate cleanly on SIGINT
  * Use stdin as VT for current/none vt selections
  * config: Skip reading config in session worker
  * config: Add general.source_profile
  * config: Fix tests for general section
  * docs: Document new general section
  * ci: Disable automatic github mirroring
  * Add installation instructions on Gentoo
  * Make sure to require codec in tokio-codec feature
* Thu Nov  5 2020 Denis Kondratenko <denis.kondratenko@suse.com>
- add missed group requirement (issue could be seen during installation)
- correct home directory for the greeter user
* Tue Sep 15 2020 Denis Kondratenko <denis.kondratenko@suse.com>
- fix /etc/greetd dir permissions
- relocate pam file to /usr/etc
* Wed Sep  9 2020 Denis Kondratenko <denis.kondratenko@suse.com>
- add missing state and run dirs
* Wed Sep  9 2020 Denis Kondratenko <denis.kondratenko@suse.com>
- fix file permissions to correct greeter user
* Tue Sep  8 2020 Denis Kondratenko <denis.kondratenko@suse.com>
- Add greetd.pam file and fixed directory permission in etc
* Mon Sep  7 2020 Denis Kondratenko <denis.kondratenko@suse.com>
- Initial v0.6.1 greetd package
  * includes greetd service
  * includes agreety text-based greeter
